@@ -21,7 +21,6 @@
 #include "lp_data/HighsModelObject.h"
 #include "lp_data/HighsOptions.h"
 #include "lp_data/HighsStatus.h"
-#include "presolve/ICrash.h"
 #include "presolve/Presolve.h"
 #include "util/HighsTimer.h"
 
@@ -174,8 +173,6 @@ class Highs {
    */
   const HighsSolution& getSolution() const;
 
-  const ICrashInfo& getICrashInfo() const;
-
   /**
    * @brief Returns the HighsBasis
    */
@@ -693,7 +690,6 @@ class Highs {
   HighsSolution solution_;
   HighsBasis basis_;
   HighsLp lp_;
-  ICrashInfo icrash_info_;
 
   HighsTimer timer_;
 
